@@ -15,27 +15,32 @@ namespace Predis;
  * Implements a lightweight PSR-0 compliant autoloader.
  *
  * @author Eric Naeseth <eric@thumbtack.com>
+ * @author Daniele Alessandri <suppakilla@gmail.com>
  */
 class Autoloader
 {
-    private $baseDir;
+    private $directory;
     private $prefix;
+    private $prefixLength;
 
     /**
      * @param string $baseDirectory Base directory where the source files are located.
      */
-    public function __construct($baseDirectory = null)
+    public function __construct($baseDirectory = __DIR__)
     {
-        $this->baseDir = $baseDirectory ?: dirname(__FILE__);
+        $this->directory = $baseDirectory;
         $this->prefix = __NAMESPACE__ . '\\';
+        $this->prefixLength = strlen($this->prefix);
     }
 
     /**
      * Registers the autoloader class with the PHP SPL autoloader.
+     *
+     * @param boolean $prepend Prepend the autoloader on the stack instead of appending it.
      */
-    public static function register()
+    public static function register($prepend = false)
     {
-        spl_autoload_register(array(new self, 'autoload'));
+        spl_autoload_register(array(new self, 'autoload'), true, $prepend);
     }
 
     /**
@@ -45,13 +50,12 @@ class Autoloader
      */
     public function autoload($className)
     {
-        if (0 !== strpos($className, $this->prefix)) {
-            return;
+        if (0 === strpos($className, $this->prefix)) {
+            $parts = explode('\\', substr($className, $this->prefixLength));
+            $filepath = $this->directory.DIRECTORY_SEPARATOR.implode(DIRECTORY_SEPARATOR, $parts).'.php';
+            if (is_file($filepath)) {
+                require($filepath);
+            }
         }
-
-        $relativeClassName = substr($className, strlen($this->prefix));
-        $classNameParts = explode('\\', $relativeClassName);
-
-        require_once $this->baseDir.DIRECTORY_SEPARATOR.implode(DIRECTORY_SEPARATOR, $classNameParts).'.php';
     }
 }
