@@ -13,6 +13,7 @@ namespace Predis\Pipeline;
 
 use Predis\ServerException;
 use Predis\Network\IConnection;
+use Predis\Network\IConnectionReplication;
 
 /**
  * Implements the standard pipeline executor strategy used
@@ -23,6 +24,20 @@ use Predis\Network\IConnection;
  */
 class StandardExecutor implements IPipelineExecutor
 {
+    /**
+     * Allows the pipeline executor to perform operations on the
+     * connection before starting to execute the commands stored
+     * in the pipeline.
+     *
+     * @param IConnection Connection instance.
+     */
+    protected function checkConnection(IConnection $connection)
+    {
+        if ($connection instanceof IConnectionReplication) {
+            $connection->switchTo('master');
+        }
+    }
+
     /**
      * {@inheritdoc}
      */
@@ -31,6 +46,8 @@ class StandardExecutor implements IPipelineExecutor
         $sizeofPipe = count($commands);
         $values = array();
 
+        $this->checkConnection($connection);
+
         foreach ($commands as $command) {
             $connection->writeCommand($command);
         }
